# == define mountfilesystem::mount
#
#  a defined resource (are blocks of Puppet code that can be evaluated multiple times with different 
#  parameters) called 'mountfilesystem::mount' is used to mount file sytem/storage
#
#
# === Parameters
# $type, $location, $fstype, $dir_mode, $file_mode, $url, $account_name, $key
#
# === Variables
# $type - Type of storage system trying to mount. Eg. Azure, network, etc
# $location - Location where the file system to be mounted and handle recursive parent directory creation
# $fstype - File system type to be mounted
# $dir_mode - Mode of the directory after mount
# $file_mode - Mode of the file after mount 
# $url - Azure file storage system identifier/URL
# $account_name - Domain name/account name that used to access the storage
# $key - The security key/password to access/mount Azure file system
#
#
# === Examples
#
#
# a custom defined  resource 'mountfilesystem::mount' uses two standard puppet resources 'file' and 
# 'mount' and gets passed values from the mount.pp create_resources function if variables are 
# not statically set, have to be named exactly as keys from the {::node_role}.yaml 
# This is then used to create mount multiple file system under different locations
#
#
# === Authors
#
# Benson Arokiadoss, b.arokiadoss@kainos.com

define mountfilesystem::mount ($type, $location, $fstype, $dir_mode, $file_mode, $url, $account_name, $key) {

  if ($type == "azure") 
      { 
        $options = "vers=3.0,username=${account_name},password=${key},dir_mode=${dir_mode},file_mode=${file_mode}"
      } 
  elsif ($type == "network") 
      { 
      $options = "dir_mode=${dir_mode},file_mode=${file_mode}" 
      } 
  else 
      { 
      $options = "defaults"
      }

  file { "${location}":
        ensure   => directory,
      }
  
  mount { "${location}":
        ensure   => "mounted",
        atboot   => true,
        fstype   => "${fstype}",
        device   => "${url}",
        options  => "${options}",
        require  => File["${location}"],
      }   

}